@@ -61,19 +61,20 @@ test_that('Test event adding', {
     uids <- c(4000001, 4000002, 4000004)
     addPgEvent(db = tmpDb, UIDs = uids, binary = bin, eventType = 'MyNewEvent', type='click')
     addPgEvent(db = tmpDb, UIDs = uids, binary = bin, eventType = 'MyNewEvent', type='click')
-
+    now <- format(nowUTC(), '%Y-%m-%d %H:%M:%S')
+    addPgEvent(db = tmpDb, eventType='BlankEvent', type='click', start=now, end=now)
     con <- dbConnect(tmpDb, drv=SQLite())
     ev <- dbReadTable(con, 'Click_Detector_OfflineEvents')
-    expect_equal(nrow(ev), 1)
+    expect_equal(nrow(ev), 2)
     click <- dbReadTable(con, 'Click_Detector_OfflineClicks')
     lookup <- dbReadTable(con, 'Lookup')
     # test matching data got added
-    expect_true('MyNewEvent' %in% lookup$Code)
+    expect_true(all(c('MyNewEvent', 'BlankEvent') %in% lookup$Code))
     expect_equal(click$UID, uids)
-    expect_equal(ev$UID, unique(click$parentUID))
-    expect_equal(ev$nClicks, nrow(click))
-    expect_equal(ev$eventType, 'MyNewEvent')
-    expect_equal(ev$EventEnd, click$UTC[3])
+    expect_equal(ev$UID[1], unique(click$parentUID))
+    expect_equal(ev$nClicks, c(nrow(click), 0))
+    expect_equal(ev$eventType, c('MyNewEvent', 'BlankEvent'))
+    expect_equal(ev$EventEnd, c(click$UTC[3], now))
     expect_error(addPgEvent(db='DNE'))
     # clean up test rows
     del <- dbSendQuery(con, 'DELETE FROM Click_Detector_OfflineEvents')
@@ -86,20 +87,21 @@ test_that('Test event adding', {
     # Add DG style
     addPgEvent(db = tmpDb, UIDs = uids, binary = bin, eventType = 'MyNewEventDG', type='dg', comment='DG')
     addPgEvent(db = tmpDb, UIDs = uids, binary = bin, eventType = 'MyNewEventDG', type='dg')
+    addPgEvent(db = tmpDb, eventType = 'BlankDG', type='dg', start=now, end=now)
 
     con <- dbConnect(tmpDb, drv=SQLite())
     ev <- dbReadTable(con, 'Detection_Grouper')
-    expect_equal(nrow(ev), 1)
+    expect_equal(nrow(ev), 2)
     click <- dbReadTable(con, 'Detection_Grouper_Children')
     lookup <- dbReadTable(con, 'Lookup')
     # test matching data got added
     expect_true('MyNewEventDG' %in% lookup$Code)
     expect_equal(click$UID, uids)
-    expect_equal(ev$UID, unique(click$parentUID))
-    expect_equal(ev$DataCount, nrow(click))
-    expect_equal(ev$eventType, 'MyNewEventDG')
-    expect_equal(ev$EndTime, click$UTC[3])
-    expect_equal(ev$Text_Annotation, 'DG')
+    expect_equal(ev$UID[1], unique(click$parentUID))
+    expect_equal(ev$DataCount, c(nrow(click), 0))
+    expect_equal(ev$eventType, c('MyNewEventDG', 'BlankDG'))
+    expect_equal(ev$EndTime, c(click$UTC[3], now))
+    expect_equal(ev$Text_Annotation, c('DG', paste0('Created by PAMmisc v', packageVersion('PAMmisc'))))
     # clean up test rows
     del <- dbSendQuery(con, 'DELETE FROM Detection_Grouper')
     dbClearResult(del)
